@@ -13,7 +13,7 @@ from os.path import (
 )
 import platform
 
-VERSION = "4.0.0"
+VERSION = "4.0.6"
 
 
 TRACE = 5
@@ -54,13 +54,15 @@ class MyLogger(logging.Logger):
 
 	def __init__(self, *args):
 		logging.Logger.__init__(self, *args)
+		self._verbosity = 3
+		self._timeEnable = False
 
 	def setVerbosity(self, verbosity: int) -> None:
 		self.setLevel(self.levelsByVerbosity[verbosity])
 		self._verbosity = verbosity
 
 	def getVerbosity(self) -> int:
-		return getattr(self, "_verbosity", 3)  # FIXME
+		return self._verbosity
 
 	def trace(self, msg: str):
 		self.log(TRACE, msg)
@@ -73,7 +75,7 @@ class MyLogger(logging.Logger):
 		return self.getVerbosity() >= 4
 
 	def newFormatter(self):
-		timeEnable = getattr(self, "_timeEnable", False)
+		timeEnable = self._timeEnable
 		if timeEnable:
 			fmt = "%(asctime)s [%(levelname)s] %(message)s"
 		else:
@@ -87,7 +89,7 @@ class MyLogger(logging.Logger):
 			handler.setFormatter(formatter)
 
 	def addHandler(self, handler: "logging.Handler"):
-		# if want to add separate format (new pref keys and flags) for ui_gtk
+		# if want to add separate format (new config keys and flags) for ui_gtk
 		# and ui_tk, you need to remove this function and run handler.setFormatter
 		# in ui_gtk and ui_tk
 		logging.Logger.addHandler(self, handler)
@@ -185,12 +187,6 @@ class StdLogHandler(logging.Handler):
 		fp.write(msg + "\n")
 		fp.flush()
 
-#	def exception(self, msg: str) -> None:
-#		if not self.noColor:
-#			msg = self.startRed + msg + self.endFormat
-#		sys.stderr.write(msg + "\n")
-#		sys.stderr.flush()
-
 
 def checkCreateConfDir() -> None:
 	if not isdir(confDir):
@@ -217,7 +213,10 @@ sys.excepthook = lambda *exc_info: log.critical(
 	)
 )
 
-sysName = platform.system()
+sysName = platform.system().lower()
+# platform.system() is in	["Linux", "Windows", "Darwin", "FreeBSD"]
+# sysName is in				["linux", "windows", "darwin', "freebsd"]
+
 
 # can set env var WARNINGS to:
 # "error", "ignore", "always", "default", "module", "once"
@@ -251,7 +250,7 @@ if os.sep == "/":  # Operating system is Unix-Like
 	user = os.getenv("USER")
 	tmpDir = "/tmp"
 	# os.name == "posix" # FIXME
-	if sysName == "Darwin":  # MacOS X
+	if sysName == "darwin":  # MacOS X
 		_libDir = join(homeDir, "Library")
 		confDir = join(_libDir, "Preferences", "PyGlossary")
 		# or maybe: join(_libDir, "PyGlossary")
