@@ -78,14 +78,17 @@ class DataEntry(BaseEntry):
 		# fix filename depending on operating system? FIXME
 		fpath = join(directory, fname)
 		fdir = dirname(fpath)
-		if not exists(fdir):
-			os.makedirs(fdir)
-		if self._tmpPath:
-			shutil.move(self._tmpPath, fpath)
-			self._tmpPath = fpath
-		else:
-			with open(fpath, "wb") as toFile:
-				toFile.write(self._data)
+		try:
+			os.makedirs(fdir, mode=0o755, exist_ok=True)
+			if self._tmpPath:
+				shutil.move(self._tmpPath, fpath)
+				self._tmpPath = fpath
+			else:
+				with open(fpath, "wb") as toFile:
+					toFile.write(self._data)
+		except Exception:
+			log.exception(f"error while saving {fpath}")
+			return ""
 		return fpath
 
 	@property
@@ -230,7 +233,7 @@ class Entry(BaseEntry):
 		if key is None:
 			key = Entry.defaultSortKey
 
-		if glos.getPref("enable_alts", True):
+		if glos.getConfig("enable_alts", True):
 			b_sep = Entry.b_sep
 			if glos._rawEntryCompress:
 				return lambda x: key(loads(decompress(x))[0].split(b_sep)[0])
@@ -280,7 +283,10 @@ class Entry(BaseEntry):
 		self._byteProgress = byteProgress  # Optional[Tuple[int, int]]
 
 	def __repr__(self):
-		return f"Entry({self._word!r}, {self._defi!r}, defiFormat={self._defiFormat!r})"
+		return (
+			f"Entry({self._word!r}, {self._defi!r}, "
+			f"defiFormat={self._defiFormat!r})"
+		)
 
 	@property
 	def s_word(self):
@@ -492,7 +498,7 @@ class Entry(BaseEntry):
 		else:
 			defiFormat = defaultDefiFormat
 
-		if glos.getPref("enable_alts", True):
+		if glos.getConfig("enable_alts", True):
 			word = word.split(cls.sep)
 
 		return cls(
