@@ -54,12 +54,6 @@ class NonEmptyWordFilter(EntryFilter):
 	def run(self, entry: BaseEntry, index: int) -> "Optional[BaseEntry]":
 		if not entry.s_word:
 			return
-#		words = entry.l_word
-#		if not words:
-#			return
-#		wordsStr = "".join([w.strip() for w in words])
-#		if not wordsStr:
-#			return
 		return entry
 
 
@@ -134,17 +128,15 @@ class RemoveHtmlTags(EntryFilter):
 	name = "remove_html"
 
 	def __init__(self, glos: "GlossaryType", tags: "List[str]"):
+		import re
 		self.glos = glos
 		self.tags = tags
+		tagsRE = "|".join(self.tags)
+		self.pattern = re.compile(f"<.?({tagsRE})[^>]*>")
 
 	def run(self, entry: BaseEntry, index: int) -> "Optional[BaseEntry]":
-		import re
-
 		def fixStr(st: str) -> str:
-			tagsRE = "|".join(self.tags)
-			pattern = f"<.?({tagsRE})[^>]*>"
-			st = pattern.sub("", st)
-			return st
+			return self.pattern.sub("", st)
 
 		entry.editFuncDefi(fixStr)
 		return entry
