@@ -55,7 +55,7 @@ from .langs import LangDict, Lang
 from .text_utils import (
 	fixUtf8,
 )
-
+from .compression import stdCompressions
 from .glossary_type import GlossaryType
 
 homePage = "https://github.com/ilius/pyglossary"
@@ -114,16 +114,15 @@ class Glossary(GlossaryType):
 		# and "lastUpdated"?
 	}
 
-	plugins = {}  # format name => PluginProp
-	pluginByExt = {}  # extension => PluginProp
+	plugins = {}  # type: Dict[str, PluginProp]
+	pluginByExt = {}  # type: Dict[str, PluginProp]
 
-	formatsReadOptions = {}
-	formatsWriteOptions = {}
-	formatsReadFileObj = {}  # type: Dict[str, bool]
-	formatsWriteFileObj = {}  # type: Dict[str, bool]
+	formatsReadOptions = {}  # type: Dict[str, OrderedDict[str, Any]]
+	formatsWriteOptions = {}  # type: Dict[str, OrderedDict[str, Any]]
+	# for example formatsReadOptions[format][optName] gives you the default value
 
-	readFormats = []
-	writeFormats = []
+	readFormats = []  # type: List[str]
+	writeFormats = []  # type: List[str]
 
 	@classmethod
 	def loadPlugins(cls: "ClassVar", directory: str) -> None:
@@ -188,36 +187,15 @@ class Glossary(GlossaryType):
 		Reader = prop.readerClass
 		if Reader is not None:
 			options = prop.getReadOptions()
-			extraOptions = prop.getReadExtraOptions()
-
 			cls.formatsReadOptions[format] = options
 			cls.readFormats.append(format)
-
 			Reader.formatName = format
-			if "fileObj" in extraOptions:
-				if plugin.singleFile:
-					cls.formatsReadFileObj[format] = True
-				else:
-					log.error(
-						f"plugin {format}: fileObj= argument "
-						"in Reader.open, without singleFile=True"
-					)
 
 		Writer = prop.writerClass
 		if Writer is not None:
 			options = prop.getWriteOptions()
-			extraOptions = prop.getWriteExtraOptions()
-
 			cls.formatsWriteOptions[format] = options
 			cls.writeFormats.append(format)
-			if "fileObj" in extraOptions:
-				if plugin.singleFile:
-					cls.formatsWriteFileObj[format] = True
-				else:
-					log.error(
-						f"plugin {format}: fileObj= argument "
-						"in write, without singleFile=True"
-					)
 
 		if not (Reader or Writer):
 			log.warning(f"plugin {format} has no Reader nor Writer")
@@ -236,27 +214,37 @@ class Glossary(GlossaryType):
 		filename: str,
 		format: str = "",
 		quiet: bool = False,
-	) -> str:
-		def error(msg: str) -> str:
+	) -> "Optional[Tuple[str, str, str]]":
+		"""
+			returns (filename, format, compression) or None
+		"""
+
+		def error(msg: str) -> None:
 			if not quiet:
 				log.error(msg)
-			return ""
+			return None
 
+		filenameOrig = filename
+		filenameNoExt, filename, ext, compression = cls.splitFilenameExt(filename)
+
+		plugin = None
 		if format:
 			plugin = cls.plugins[format]
-			if plugin.readerClass:
-				return plugin.name
+		else:
+			plugin = cls.pluginByExt.get(ext)
+			if not plugin:
+				plugin = cls.findPlugin(filename)
+				if not plugin:
+					return error("Unable to detect write format!")
+
+		if not plugin.canRead:
 			return error(f"plugin {plugin.name} does not support reading")
 
-		ext = get_ext(filename)
-		plugin = cls.pluginByExt.get(ext)
-		if plugin:
-			if plugin.readerClass:
-				return plugin.name
-			return error(f"plugin {plugin.name} does not support reading")
-		log.debug(f"{sorted(cls.pluginByExt.keys())}")
+		if compression in getattr(plugin.readerClass, "compressions", []):
+			compression = ""
+			filename = filenameOrig
 
-		return error(f"Could not detect input format")
+		return filename, plugin.name, compression
 
 	def clear(self) -> None:
 		self._info = odict()
@@ -287,7 +275,7 @@ class Glossary(GlossaryType):
 	def __init__(
 		self,
 		info: "Optional[Dict[str, str]]" = None,
-		ui: "Any" = None,
+		ui: "Optional[UIBase]" = None,
 	) -> None:
 		"""
 		info:	OrderedDict or dict instance, or None
@@ -316,17 +304,23 @@ class Glossary(GlossaryType):
 	def cleanup(self):
 		if not self._cleanupPathList:
 			return
-		if not self.getPref("cleanup", True):
+		if not self.getConfig("cleanup", True):
 			log.info("Not cleaning up files:")
 			log.info("\n".join(self._cleanupPathList))
 			return
 		for cleanupPath in self._cleanupPathList:
 			if isfile(cleanupPath):
 				log.debug(f"Removing file {cleanupPath}")
-				os.remove(cleanupPath)
+				try:
+					os.remove(cleanupPath)
+				except Exception:
+					log.exception(f"error removing {cleanupPath}")
 			elif isdir(cleanupPath):
 				log.debug(f"Removing directory {cleanupPath}")
-				self._removeDir(cleanupPath)
+				try:
+					self._removeDir(cleanupPath)
+				except Exception:
+					log.exception(f"error removing {cleanupPath}/")
 			else:
 				log.error(f"no such file or directory: {cleanupPath}")
 
@@ -336,27 +330,27 @@ class Glossary(GlossaryType):
 	def updateEntryFilters(self) -> None:
 		from . import entry_filters as ef
 		self._entryFilters = []
-		pref = getattr(self.ui, "pref", {})
+		config = getattr(self.ui, "config", {})
 
 		self._entryFilters.append(ef.StripEntryFilter(self))
 		self._entryFilters.append(ef.NonEmptyWordFilter(self))
 
-		if pref.get("skipResources", False):
+		if config.get("skip_resources", False):
 			self._entryFilters.append(ef.SkipDataEntryFilter(self))
 
-		if pref.get("utf8Check", True):
+		if config.get("utf8_check", True):
 			self._entryFilters.append(ef.FixUnicodeFilter(self))
 
-		if pref.get("lower", True):
+		if config.get("lower", True):
 			self._entryFilters.append(ef.LowerWordFilter(self))
 
-		if pref.get("remove_html_all", False):
+		if config.get("remove_html_all", False):
 			self._entryFilters.append(ef.RemoveHtmlTagsAll(self))
-		elif pref.get("remove_html"):
-			tags = pref.get("remove_html").split(",")
+		elif config.get("remove_html"):
+			tags = config.get("remove_html").split(",")
 			self._entryFilters.append(ef.RemoveHtmlTags(self, tags))
 
-		if pref.get("normalize_html", False):
+		if config.get("normalize_html", False):
 			self._entryFilters.append(ef.NormalizeHtml(self))
 
 		self._entryFilters.append(ef.LangEntryFilter(self))
@@ -468,11 +462,11 @@ class Glossary(GlossaryType):
 		return self._defaultDefiFormat
 
 	# TODO
-	#def _reopenReader(self, reader):
-	#	log.info(f"re-opening {reader.__class__}")
-	#	filename, options = self._readersOpenArgs[reader]
-	#	reader.close()
-	#	reader.open(filename, **options)
+	# def _reopenReader(self, reader):
+	# 	log.info(f"re-opening {reader.__class__}")
+	# 	filename, options = self._readersOpenArgs[reader]
+	# 	reader.close()
+	# 	reader.open(filename, **options)
 
 	def collectDefiFormat(
 		self,
@@ -660,9 +654,9 @@ class Glossary(GlossaryType):
 				return hf.element(ws.titleTag)
 		return hf.element("b")
 
-	def getPref(self, name: str, default: "Optional[str]") -> "Optional[str]":
+	def getConfig(self, name: str, default: "Optional[str]") -> "Optional[str]":
 		if self.ui:
-			return self.ui.pref.get(name, default)
+			return self.ui.config.get(name, default)
 		else:
 			return default
 
@@ -767,7 +761,7 @@ class Glossary(GlossaryType):
 		# And we don't have to check for write access to cacheDir because it's
 		# inside user's home dir. But input glossary might be in a directory
 		# that we don't have write access to.
-		# still maybe add a pref key to decide if we should always use cacheDir
+		# still maybe add a config key to decide if we should always use cacheDir
 		# if self._hasWriteAccessToDir(f"{filename}_res", os.W_OK):
 		# 	self.tmpDataDir = f"{filename}_res"
 		# else:
@@ -784,11 +778,17 @@ class Glossary(GlossaryType):
 			)
 
 		###
-		format = self.detectInputFormat(filename, format=format)
-		if not format:
+		inputArgs = self.detectInputFormat(filename, format=format)
+		if inputArgs is None:
 			return False
+		origFilename = filename
+		filename, format, compression = inputArgs
 
-		validOptionKeys = self.formatsReadOptions[format]
+		if compression:
+			from pyglossary.glossary_utils import uncompress
+			uncompress(origFilename, filename, compression)
+
+		validOptionKeys = list(self.formatsReadOptions[format].keys())
 		for key in list(options.keys()):
 			if key not in validOptionKeys:
 				log.error(
@@ -945,7 +945,10 @@ class Glossary(GlossaryType):
 		if not ext and len(filenameNoExt) < 5:
 			filenameNoExt, ext = "", filenameNoExt
 
-		if ext in (".gz", ".bz2", ".zip"):
+		if not ext:
+			return filename, filename, "", ""
+
+		if ext[1:] in stdCompressions + ("zip",):
 			compression = ext[1:]
 			filename = filenameNoExt
 			filenameNoExt, ext = splitext(filename)
@@ -988,6 +991,7 @@ class Glossary(GlossaryType):
 			filename = splitext(inputFilename)[0] + plugin.ext
 			return filename, plugin.name, ""
 
+		filenameOrig = filename
 		filenameNoExt, filename, ext, compression = cls.splitFilenameExt(filename)
 
 		if not plugin:
@@ -1001,6 +1005,10 @@ class Glossary(GlossaryType):
 		if not plugin.canWrite:
 			return error(f"plugin {plugin.name} does not support writing")
 
+		if compression in getattr(plugin.writerClass, "compressions", []):
+			compression = ""
+			filename = filenameOrig
+
 		if addExt:
 			if not filenameNoExt:
 				if inputFilename:
@@ -1050,10 +1058,11 @@ class Glossary(GlossaryType):
 		"""
 		filename = abspath(filename)
 
-		validOptionKeys = self.formatsWriteOptions.get(format)
-		if validOptionKeys is None:
+		validOptions = self.formatsWriteOptions.get(format)
+		if validOptions is None:
 			log.critical(f"No write support for {format!r} format")
 			return
+		validOptionKeys = list(validOptions.keys())
 		for key in list(options.keys()):
 			if key not in validOptionKeys:
 				log.error(
@@ -1161,7 +1170,7 @@ class Glossary(GlossaryType):
 			else:
 				genList.append(gen)
 
-			if self.getPref("save_info_json", False):
+			if self.getConfig("save_info_json", False):
 				infoWriter = self._createWriter("Info", {})
 				filenameNoExt, _, _, _ = Glossary.splitFilenameExt(filename)
 				infoWriter.open(f"{filenameNoExt}.info")
@@ -1192,9 +1201,9 @@ class Glossary(GlossaryType):
 
 		return filename
 
-	def _compressOutDir(self, filename: str, compression: str) -> str:
-		from pyglossary.glossary_utils import compressOutDir
-		return compressOutDir(filename, compression)
+	def _compressOutput(self, filename: str, compression: str) -> str:
+		from pyglossary.glossary_utils import compress
+		return compress(filename, compression)
 
 	def convert(
 		self,
@@ -1276,7 +1285,7 @@ class Glossary(GlossaryType):
 			return
 
 		if compression:
-			finalOutputFile = self._compressOutDir(finalOutputFile, compression)
+			finalOutputFile = self._compressOutput(finalOutputFile, compression)
 
 		log.info(f"Writing file {finalOutputFile!r} done.")
 		log.info(f"Running time of convert: {now()-tm0:.1f} seconds")
@@ -1291,7 +1300,6 @@ class Glossary(GlossaryType):
 		self,
 		entryFmt: str = "",  # contain {word} and {defi}
 		filename: str = "",
-		fileObj: "Optional[file]" = None,
 		writeInfo: bool = True,
 		wordEscapeFunc: "Optional[Callable]" = None,
 		defiEscapeFunc: "Optional[Callable]" = None,
@@ -1304,27 +1312,16 @@ class Glossary(GlossaryType):
 		newline: str = "\n",
 		resources: bool = True,
 	) -> "Generator[None, BaseEntry, None]":
-		import codecs
+		from .compression import compressionOpen as c_open
 		if not entryFmt:
 			raise ValueError("entryFmt argument is missing")
-		if filename and fileObj:
-			raise ValueError(f"both filename and fileObj are passed")
 		if not filename:
 			filename = self._filename + ext
 
 		if not outInfoKeysAliasDict:
 			outInfoKeysAliasDict = {}
 
-		if fileObj:
-			mode = getattr(fileObj, "mode", "")
-			if isinstance(mode, int):
-				# for gzip.open with BytesIO, mode == 2
-				pass
-			elif "b" in mode:
-				# binFileObj = fileObj  # needed?
-				fileObj = codecs.getwriter(encoding)(fileObj)
-		else:
-			fileObj = open(filename, "w", encoding=encoding, newline=newline)
+		fileObj = c_open(filename, mode="wt", encoding=encoding, newline=newline)
 
 		fileObj.write(head)
 		if writeInfo:
@@ -1368,7 +1365,7 @@ class Glossary(GlossaryType):
 			defi = entry.defi
 			if word.startswith("#"):  # FIXME
 				continue
-			# if self.getPref("enable_alts", True):  # FIXME
+			# if self.getConfig("enable_alts", True):  # FIXME
 
 			if wordEscapeFunc is not None:
 				word = wordEscapeFunc(word)
@@ -1386,14 +1383,12 @@ class Glossary(GlossaryType):
 	def writeTabfile(
 		self,
 		filename: str = "",
-		fileObj: "Optional[file]" = None,
 		**kwargs,
 	) -> "Generator[None, BaseEntry, None]":
 		from .text_utils import escapeNTB
 		yield from self.writeTxt(
 			entryFmt="{word}\t{defi}\n",
 			filename=filename,
-			fileObj=fileObj,
 			wordEscapeFunc=escapeNTB,
 			defiEscapeFunc=escapeNTB,
 			ext=".txt",
@@ -1414,7 +1409,7 @@ class Glossary(GlossaryType):
 			return
 		self.ui.progress(
 			min(pos + 1, total) / total,
-			f"{pos:d} / {total:d} {unit}",
+			f"{pos:,} / {total:,} {unit}",
 		)
 
 	def progressEnd(self) -> None:
