@@ -1,5 +1,8 @@
 import os
 import shutil
+import logging
+
+log = logging.getLogger("pyglossary")
 
 
 class indir(object):
@@ -34,6 +37,25 @@ class indir(object):
 		self.oldpwd = None
 
 
+def runDictzip(filename: str) -> None:
+	import shutil
+	import subprocess
+	dictzipCmd = shutil.which("dictzip")
+	if not dictzipCmd:
+		return False
+	(out, err) = subprocess.Popen(
+		[dictzipCmd, filename],
+		stdout=subprocess.PIPE
+	).communicate()
+	log.debug(f"dictzip command: {dictzipCmd!r}")
+	if err:
+		err = err.replace('\n', ' ')
+		log.error(f"dictzip error: {err}")
+	if out:
+		out = out.replace('\n', ' ')
+		log.error(f"dictzip error: {out}")
+
+
 def my_url_show(link: str) -> None:
 	import subprocess
 	for path in (
