@@ -4,7 +4,6 @@ from formats_common import *
 enable = False
 format = "BabylonBdc"
 description = "Babylon (bdc)"
-extentions = [".bdc"]
-readOptions = []
-writeOptions = []
-
+extensions = (".bdc",)
+singleFile = True
+optionsProp = {}
