@@ -1,10 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2008-2016 Saeed Rasooli <saeed.gnu@gmail.com> (ilius)
-# Copyright © 2011-2012 kubtek <kubtek@gmail.com>
-# This file is part of PyGlossary project, http://github.com/ilius/pyglossary
-# Thanks to Raul Fernandes <rgfbr@yahoo.com.br> and Karl Grill
-#	   for reverse engineering
+# Copyright © 2008-2020 Saeed Rasooli <saeed.gnu@gmail.com> (ilius)
 #
 # This program is a free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,15 +18,33 @@
 
 from formats_common import *
 from .bgl_reader import BglReader as Reader
-from .bgl_reader import readOptions
+from .bgl_reader import optionsProp
 
 enable = True
 format = "BabylonBgl"
 description = "Babylon (bgl)"
-extentions = [".bgl"]
-
-writeOptions = []
-supportsAlternates = True
+extensions = (".bgl",)
+singleFile = True
+tools = [
+	{
+		"name": "Babylon Translator",
+		"web": "https://www.babylon-software.com/",
+		"platforms": ["Windows"],
+		"license": "Proprietary",
+	},
+	{
+		"name": "GoldenDict",
+		"web": "http://goldendict.org/",
+		"platforms": ["Linux", "Windows"],
+		"license": "GPL",
+	},
+	{
+		"name": "GoldenDict Mobile",
+		"web": "http://goldendict.mobi/",
+		"platforms": ["Android"],
+		"license": "Unknown",
+	},
+]
 # progressbar = DEFAULT_YES
 
 # FIXME: document type of read/write options
