@@ -54,7 +54,30 @@ optionsProp = {
 }
 
 
+class TextFilePosWrapper(object):
+	def __init__(self, fileobj, encoding):
+		self.fileobj = fileobj
+		self._encoding = encoding
+		self.pos = 0
+
+	def __iter__(self):
+		return self
+
+	def close(self):
+		self.fileobj.close()
+
+	def __next__(self):
+		line = self.fileobj.__next__()
+		self.pos += len(line.encode(self._encoding))
+		return line
+
+	def tell(self):
+		return self.pos
+
+
 class Reader(object):
+	compressions = stdCompressions
+
 	_encoding: str = "utf-8"
 	_delimiter: str = ","
 
@@ -78,7 +101,11 @@ class Reader(object):
 		filename: str,
 	) -> None:
 		self._filename = filename
-		self._file = open(filename, "r", encoding=self._encoding)
+		cfile = compressionOpen(filename, mode="rt", encoding=self._encoding)
+		cfile.seek(0, 2)
+		self._fileSize = cfile.tell()
+		cfile.seek(0)
+		self._file = TextFilePosWrapper(cfile, self._encoding)
 		self._csvReader = csv.reader(
 			self._file,
 			dialect="excel",
@@ -105,12 +132,14 @@ class Reader(object):
 		if self._file:
 			try:
 				self._file.close()
-			except:
+			except Exception:
 				log.exception("error while closing csv file")
 		self.clear()
 
 	def __len__(self) -> int:
 		if self._wordCount is None:
+			if hasattr(self._file, "compression"):
+				return 0
 			log.debug("Try not to use len(reader) as it takes extra time")
 			self._wordCount = fileCountLines(self._filename) - \
 				self._leadingLinesCount
@@ -146,7 +175,11 @@ class Reader(object):
 				pass
 			else:
 				word = [word] + alts
-			yield self._glos.newEntry(word, defi)
+			yield self._glos.newEntry(
+				word,
+				defi,
+				byteProgress=(self._file.tell(), self._fileSize),
+			)
 		self._wordCount = wordCount
 
 		resDir = self._resDir
@@ -159,6 +192,8 @@ class Reader(object):
 
 
 class Writer(object):
+	compressions = stdCompressions
+
 	_encoding: str = "utf-8"
 	_resources: bool = True
 	_delimiter: str = ","
@@ -170,7 +205,7 @@ class Writer(object):
 
 	def open(self, filename: str):
 		self._filename = filename
-		self._file = open(filename, "w", encoding=self._encoding)
+		self._file = compressionOpen(filename, mode="wt", encoding=self._encoding)
 		self._resDir = resDir = filename + "_res"
 		self._csvWriter = csv.writer(
 			self._file,
@@ -225,4 +260,3 @@ class Writer(object):
 				row.append(",".join(alts))
 
 			writer.writerow(row)
-
