@@ -25,6 +25,7 @@ from pyglossary.flags import *
 from pyglossary import core
 from pyglossary.core import (
 	pip,
+	cacheDir,
 )
 from pyglossary.option import *
 from pyglossary.text_utils import (
@@ -32,6 +33,10 @@ from pyglossary.text_utils import (
 	toBytes,
 	replaceStringTable,
 )
+from pyglossary.compression import (
+	compressionOpen,
+	stdCompressions,
+)
 from pyglossary.os_utils import indir
 from pyglossary.entry_base import BaseEntry
 
