@@ -1,7 +1,10 @@
 from pyglossary.file_utils import fileCountLines
 from pyglossary.entry_base import BaseEntry
 from pyglossary.entry import Entry, DataEntry
-
+from pyglossary.compression import (
+	compressionOpen,
+	stdCompressions,
+)
 from pyglossary.glossary_type import GlossaryType
 
 import os
@@ -14,6 +17,8 @@ log = logging.getLogger("pyglossary")
 class TextGlossaryReader(object):
 	_encoding = "utf-8"
 
+	compressions = stdCompressions
+
 	def __init__(self, glos: GlossaryType, hasInfo: bool = True):
 		self._glos = glos
 		self._filename = ""
@@ -36,13 +41,15 @@ class TextGlossaryReader(object):
 
 	def open(self, filename: str) -> None:
 		self._filename = filename
-		self._file = open(filename, "r", encoding=self._encoding)
-		if self._hasInfo:
-			self.loadInfo()
+		self._file = compressionOpen(filename, mode="rt", encoding=self._encoding)
 		if not self._wordCount:
-			self._fileSize = os.path.getsize(filename)
+			self._file.seek(0, 2)
+			self._fileSize = self._file.tell()
+			self._file.seek(0)
 			log.debug(f"File size of {filename}: {self._fileSize}")
 			self._glos.setInfo("input_file_size", f"{self._fileSize}")
+		if self._hasInfo:
+			self.loadInfo()
 
 	def openNextFile(self) -> bool:
 		self.close()
@@ -53,7 +60,7 @@ class TextGlossaryReader(object):
 			return False
 		self._fileIndex += 1
 		log.info(f"Reading next file: {nextFilename}")
-		self._file = open(nextFilename, "r", encoding=self._encoding)
+		self._file = compressionOpen(nextFilename, "rt", encoding=self._encoding)
 		if self._hasInfo:
 			self.loadInfo()
 		return True
