@@ -169,26 +169,6 @@ def replacePostSpaceChar(st: str, ch: str) -> str:
 	)
 
 
-def runDictzip(filename: str) -> None:
-	import subprocess
-	dictzipCmd = "/usr/bin/dictzip"  # Save in pref FIXME
-	if not os.path.isfile(dictzipCmd):
-		return False
-	if filename[-4:] == ".ifo":
-		filename = filename[:-4]
-	(out, err) = subprocess.Popen(
-		[dictzipCmd, filename + ".dict"],
-		stdout=subprocess.PIPE
-	).communicate()
-#	out = p3[1].read()
-#	err = p3[2].read()
-#	log.debug(f"dictzip command: {dictzipCmd!r}")
-#	if err:
-#		log.error(f"dictzip error: {err.replace('\n', ' ')}")
-#	if out:
-#		log.error(f"dictzip error: {out.replace('\n', ' ')}")
-
-
 def isControlChar(y: int) -> bool:
 	# y: char code
 	if y < 32 and chr(y) not in "\t\n\r\v":
