@@ -25,9 +25,7 @@ sudo pip3 install prompt_toolkit
 
 import sys
 import os
-from os.path import dirname, join, abspath, isdir, isfile, isabs, islink
-import stat
-import time
+from os.path import dirname, join, abspath, isdir, isabs
 import logging
 from collections import OrderedDict
 
@@ -38,16 +36,73 @@ import json
 # readline's complete func silently (and stupidly) hides any exception
 # and only shows the print if it's in the first line of function. very awkward!
 
-#import atexit
+from pyglossary.core import confDir
+from pyglossary.glossary import Glossary
+from pyglossary.ui import ui_cmd
+
 
 from prompt_toolkit import prompt as promptLow
 from prompt_toolkit.history import FileHistory
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.completion.word_completer import WordCompleter
+from prompt_toolkit.shortcuts import confirm, PromptSession
+from prompt_toolkit.key_binding import KeyBindings
+from prompt_toolkit.keys import Keys
+
+
+class MiniCheckBoxPrompt(object):
+	def __init__(
+		self,
+		message: str = "",
+		fmt: str = "{message}: {check}",
+		value: bool = False,
+	):
+		self.message = message
+		self.fmt = fmt
+		self.value = value
+
+	def formatMessage(self):
+		return self.fmt.format(
+			check="[x]" if self.value else "[ ]",
+			message=self.message,
+		)
+
+	def __pt_formatted_text__(self):
+		return [("", self.formatMessage())]
+
+
+def checkbox_prompt(
+	message: str,
+	default: bool,
+) -> PromptSession[bool]:
+	"""
+	Create a `PromptSession` object for the 'confirm' function.
+	"""
+	bindings = KeyBindings()
+
+	check = MiniCheckBoxPrompt(message=message, value=default)
+
+	@bindings.add(" ")
+	def space(event: "E") -> None:
+		check.value = not check.value
+		# cursor_pos = check.formatMessage().find("[") + 1
+		# cur_cursor_pos = session.default_buffer.cursor_position
+		# print(f"cur_cursor_pos={cur_cursor_pos}, cursor_pos={cursor_pos}")
+		# session.default_buffer.cursor_position = cursor_pos
+
+	@bindings.add(Keys.Any)
+	def _(event: "E") -> None:
+		" Disallow inserting other text. "
+		pass
+
+	complete_message = check
+	session: PromptSession[bool] = PromptSession(
+		complete_message,
+		key_bindings=bindings
+	)
+	session.prompt()
+	return check.value
 
-from pyglossary.core import confDir
-from pyglossary.glossary import Glossary
-from pyglossary.ui import ui_cmd
 
 log = logging.getLogger("pyglossary")
 
@@ -94,7 +149,7 @@ def prompt(
 		kwargs["default"] = ""
 	text = promptLow(message=message, **kwargs)
 	if multiline and text == "!m":
-		print("Entering Multi-line mode, press Alt+Enter to end")
+		print("Entering Multi-line mode, press Alt+ENTER to end")
 		text = promptLow(
 			message="",
 			multiline=True,
@@ -125,11 +180,15 @@ class UI(ui_cmd.UI):
 			("!cd", self.fs_cd),
 		])
 		self._finalActions = OrderedDict([
+			("formats", self.askFormats),
 			("read-options", self.askReadOptions),
 			("write-options", self.askWriteOptions),
 			("reset-read-options", self.resetReadOptions),
 			("reset-write-options", self.resetWriteOptions),
+			("config", self.askConfig),
 			("indirect", self.setIndirect),
+			("no-progressbar", self.setNoProgressbar),
+			("sort", self.setSort),
 			("show-options", self.showOptions),
 			("back", None),
 		])
@@ -138,8 +197,10 @@ class UI(ui_cmd.UI):
 		print(os.getcwd())
 
 	def get_ls_l(self, arg: str) -> str:
+		import stat
 		import pwd
 		import grp
+		import time
 		st = os.lstat(arg)
 		# os.lstat does not follow sym links, like "ls" command
 		details = [
@@ -150,7 +211,7 @@ class UI(ui_cmd.UI):
 			time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(st.st_mtime)),
 			arg,
 		]
-		if islink(arg):
+		if stat.S_ISLNK(st.st_mode):
 			details.append(f"-> {os.readlink(arg)}")
 		return "  ".join(details)
 
@@ -190,9 +251,6 @@ class UI(ui_cmd.UI):
 		os.chdir(newDir)
 		print(f"Changed current directory to: {newDir}")
 
-	def paramHistoryPath(self, name: str) -> str:
-		return join(histDir, f"param-{name}")
-
 	def askFile(self, kind: str, histName: str, varName: str, reading: bool):
 		from shlex import split as shlex_split
 		history = FileHistory(join(histDir, histName))
@@ -249,12 +307,12 @@ class UI(ui_cmd.UI):
 		)
 
 	def pluginByNameOrDesc(self, value: str) -> "Optional[PluginProp]":
-		prop = pluginByDesc.get(value)
-		if prop:
-			return prop
-		prop = Glossary.plugins.get(value)
-		if prop:
-			return prop
+		plugin = pluginByDesc.get(value)
+		if plugin:
+			return plugin
+		plugin = Glossary.plugins.get(value)
+		if plugin:
+			return plugin
 		log.error(f"internal error: invalid format name/desc {value!r}")
 		return None
 
@@ -311,15 +369,15 @@ class UI(ui_cmd.UI):
 
 	# TODO: how to handle \r and \n in NewlineOption.values?
 
-	def getRWOptionValueSuggestValues(self, prop):
-		if prop.values:
-			return [str(x) for x in prop.values]
-		if prop.typ == "bool":
+	def getOptionValueSuggestValues(self, option: "option.Option"):
+		if option.values:
+			return [str(x) for x in option.values]
+		if option.typ == "bool":
 			return ["True", "False"]
 		return None
 
-	def getRWOptionValueCompleter(self, prop):
-		values = self.getRWOptionValueSuggestValues(prop)
+	def getOptionValueCompleter(self, option: "option.Option"):
+		values = self.getOptionValueSuggestValues(option)
 		if values:
 			return WordCompleter(
 				values,
@@ -330,15 +388,16 @@ class UI(ui_cmd.UI):
 		return None
 
 	def askReadOptions(self):
-		optionNames = Glossary.formatsReadOptions.get(self._inputFormat)
-		if optionNames is None:
+		plugin = Glossary.plugins[self._inputFormat]
+		options = Glossary.formatsReadOptions.get(self._inputFormat)
+		if options is None:
 			log.error(f"internal error: invalid format {self._inputFormat!r}")
 			return
 		optionsProp = Glossary.plugins[self._inputFormat].optionsProp
 		history = FileHistory(join(histDir, f"read-options-{self._inputFormat}"))
 		auto_suggest = AutoSuggestFromHistory()
 		completer = WordCompleter(
-			optionNames,
+			options.keys(),
 			ignore_case=True,
 			match_middle=True,
 			sentence=True,
@@ -346,7 +405,7 @@ class UI(ui_cmd.UI):
 		while True:
 			try:
 				optName = prompt(
-					">> ReadOption: Name [ENTER if done]: ",
+					">> ReadOption: Name (ENTER if done): ",
 					history=history,
 					auto_suggest=auto_suggest,
 					completer=completer,
@@ -355,46 +414,61 @@ class UI(ui_cmd.UI):
 				return
 			if not optName:
 				return
-			prop = optionsProp[optName]
-			valueCompleter = self.getRWOptionValueCompleter(prop)
+			option = optionsProp[optName]
+			valueCompleter = self.getOptionValueCompleter(option)
+			default = self._readOptions.get(optName)
+			if default is None:
+				default = options[optName]
 			while True:
+				if option.typ == "bool":
+					try:
+						valueNew = checkbox_prompt(
+							f">>> ReadOption: {optName}",
+							default=default,
+						)
+					except (KeyboardInterrupt, EOFError):
+						break
+					print(f"Set read-option: {optName} = {valueNew!r}")
+					self._readOptions[optName] = valueNew
+					break
 				try:
-					optValue = prompt(
+					value = prompt(
 						f">>> ReadOption: {optName} = ",
 						history=FileHistory(join(histDir, f"option-value-{optName}")),
 						auto_suggest=AutoSuggestFromHistory(),
-						default=str(self._readOptions.get(optName, "")),
+						default=str(default),
 						completer=valueCompleter,
 					)
 				except (KeyboardInterrupt, EOFError):
 					break
-				if optValue == "":
+				if value == "":
 					if optName in self._readOptions:
 						print(f"Unset read-option {optName!r}")
 						del self._readOptions[optName]
 					# FIXME: set empty value?
 					break
-				optValueNew, ok = prop.evaluate(optValue)
-				if not ok or not prop.validate(optValueNew):
+				valueNew, ok = option.evaluate(value)
+				if not ok or not option.validate(valueNew):
 					log.error(
-						f"Invalid read option value {optName}={optValue!r}"
+						f"Invalid read option value {optName}={value!r}"
 						f" for format {self._inputFormat}"
 					)
 					continue
-				print(f"Set read-option: {optName} = {optValueNew!r}")
-				self._readOptions[optName] = optValueNew
+				print(f"Set read-option: {optName} = {valueNew!r}")
+				self._readOptions[optName] = valueNew
 				break
 
 	def askWriteOptions(self):
-		optionNames = Glossary.formatsWriteOptions.get(self._outputFormat)
-		if optionNames is None:
+		plugin = Glossary.plugins[self._inputFormat]
+		options = Glossary.formatsWriteOptions.get(self._outputFormat)
+		if options is None:
 			log.error(f"internal error: invalid format {self._outputFormat!r}")
 			return
 		optionsProp = Glossary.plugins[self._outputFormat].optionsProp
 		history = FileHistory(join(histDir, f"write-options-{self._outputFormat}"))
 		auto_suggest = AutoSuggestFromHistory()
 		completer = WordCompleter(
-			optionNames,
+			options.keys(),
 			ignore_case=True,
 			match_middle=True,
 			sentence=True,
@@ -402,7 +476,7 @@ class UI(ui_cmd.UI):
 		while True:
 			try:
 				optName = prompt(
-					">> WriteOption: Name [ENTER if done]: ",
+					">> WriteOption: Name (ENTER if done): ",
 					history=history,
 					auto_suggest=auto_suggest,
 					completer=completer,
@@ -411,34 +485,48 @@ class UI(ui_cmd.UI):
 				return
 			if not optName:
 				return
-			prop = optionsProp[optName]
-			valueCompleter = self.getRWOptionValueCompleter(prop)
+			option = optionsProp[optName]
+			valueCompleter = self.getOptionValueCompleter(option)
+			default = self._writeOptions.get(optName)
+			if default is None:
+				default = options[optName]
 			while True:
+				if option.typ == "bool":
+					try:
+						valueNew = checkbox_prompt(
+							f">>> WriteOption: {optName}",
+							default=default,
+						)
+					except (KeyboardInterrupt, EOFError):
+						break
+					print(f"Set write-option: {optName} = {valueNew!r}")
+					self._writeOptions[optName] = valueNew
+					break
 				try:
-					optValue = prompt(
+					value = prompt(
 						f">>> WriteOption: {optName} = ",
 						history=FileHistory(join(histDir, f"option-value-{optName}")),
 						auto_suggest=AutoSuggestFromHistory(),
-						default=str(self._writeOptions.get(optName, "")),
+						default=str(default),
 						completer=valueCompleter,
 					)
 				except (KeyboardInterrupt, EOFError):
 					break
-				if optValue == "":
+				if value == "":
 					if optName in self._writeOptions:
 						print(f"Unset write-option {optName!r}")
 						del self._writeOptions[optName]
 					# FIXME: set empty value?
 					break
-				optValueNew, ok = prop.evaluate(optValue)
-				if not ok or not prop.validate(optValueNew):
+				valueNew, ok = option.evaluate(value)
+				if not ok or not option.validate(valueNew):
 					log.error(
-						f"Invalid write option value {optName}={optValue!r}"
+						f"Invalid write option value {optName}={value!r}"
 						f" for format {self._outputFormat}"
 					)
 					continue
-				print(f"Set write-option: {optName} = {optValueNew!r}")
-				self._writeOptions[optName] = optValueNew
+				print(f"Set write-option: {optName} = {valueNew!r}")
+				self._writeOptions[optName] = valueNew
 				break
 
 	def resetReadOptions(self):
@@ -447,6 +535,67 @@ class UI(ui_cmd.UI):
 	def resetWriteOptions(self):
 		self._writeOptions = {}
 
+	def askConfigValue(self, configKey, option):
+		default = self.config.get(configKey, "")
+		if option.typ == "bool":
+			return str(checkbox_prompt(
+				message=f">>> Config: {configKey}",
+				default=bool(default),
+			))
+		return prompt(
+			f">>> Config: {configKey} = ",
+			history=FileHistory(join(histDir, f"config-value-{configKey}")),
+			auto_suggest=AutoSuggestFromHistory(),
+			default=str(default),
+			completer=self.getOptionValueCompleter(option),
+		)
+
+	def askConfig(self):
+		configKeys = list(sorted(self.configDefDict.keys()))
+		history = FileHistory(join(histDir, f"config-key"))
+		auto_suggest = AutoSuggestFromHistory()
+		completer = WordCompleter(
+			configKeys,
+			ignore_case=True,
+			match_middle=True,
+			sentence=True,
+		)
+
+		while True:
+			try:
+				configKey = prompt(
+					">> Config: Key (ENTER if done): ",
+					history=history,
+					auto_suggest=auto_suggest,
+					completer=completer,
+				)
+			except (KeyboardInterrupt, EOFError):
+				return
+			if not configKey:
+				return
+			option = self.configDefDict[configKey]
+			while True:
+				try:
+					value = self.askConfigValue(configKey, option)
+				except (KeyboardInterrupt, EOFError):
+					break
+				if value == "":
+					if configKey in self._configOptions:
+						print(f"Unset config {configKey!r}")
+						del self._configOptions[configKey]
+					# FIXME: set empty value?
+					break
+				valueNew, ok = option.evaluate(value)
+				if not ok or not option.validate(valueNew):
+					log.error(
+						f"Invalid config value {configKey}={value!r}"
+					)
+					continue
+				print(f"Set config: {configKey} = {valueNew!r}")
+				self._configOptions[configKey] = valueNew
+				self.config[configKey] = valueNew
+				break
+
 	def showOptions(self):
 		print(f"readOptions = {self._readOptions}")
 		print(f"writeOptions = {self._writeOptions}")
@@ -456,7 +605,24 @@ class UI(ui_cmd.UI):
 
 	def setIndirect(self):
 		self._convertOptions["direct"] = False
-		print(f"Switched to indirect mode")
+		print("Switched to indirect mode")
+
+	def setNoProgressbar(self):
+		self._convertOptions["progressbar"] = False
+		print("Disabled progress bar")
+
+	def setSort(self):
+		from pyglossary.entry import Entry
+		try:
+			value = checkbox_prompt(
+				message=f">> Enable Sort",
+				default=self._convertOptions.get("sort", False),
+			)
+		except (KeyboardInterrupt, EOFError):
+			return
+		self._convertOptions["sort"] = value
+		if value:
+			self._convertOptions["defaultSortKey"] = Entry.defaultSortKey
 
 	def askFinalAction(self) -> "Optional[str]":
 		history = FileHistory(join(histDir, "action"))
@@ -515,8 +681,9 @@ class UI(ui_cmd.UI):
 
 	def checkInputFormat(self, forceAsk: bool = False):
 		if not forceAsk:
-			inputFormat = Glossary.detectInputFormat(self._inputFilename, quiet=True)
-			if inputFormat:
+			inputArgs = Glossary.detectInputFormat(self._inputFilename, quiet=True)
+			if inputArgs:
+				inputFormat = inputArgs[1]
 				self._inputFormat = inputFormat
 				return
 		self._inputFormat = self.askInputFormat()
@@ -533,12 +700,84 @@ class UI(ui_cmd.UI):
 				return
 		self._outputFormat = self.askOutputFormat()
 
+	def askFormats(self):
+		self.checkInputFormat(forceAsk=True)
+		self.checkOutputFormat(forceAsk=True)
+
 	def askInputOutputAgain(self):
 		self.askInputFile()
 		self.checkInputFormat(forceAsk=True)
 		self.askOutputFile()
 		self.checkOutputFormat(forceAsk=True)
 
+	def printNonInteractiveCommand(self):
+		from shlex import quote
+		cmd = [
+			ui_cmd.COMMAND,
+			quote(self._inputFilename),
+			quote(self._outputFilename),
+			quote(f"--read-format={self._inputFormat}"),
+			quote(f"--write-format={self._outputFormat}"),
+		]
+
+		if self._readOptions:
+			optionsJson = json.dumps(self._readOptions, ensure_ascii=True)
+			cmd.append(quote(f"--json-read-options={optionsJson}"))
+
+		if self._writeOptions:
+			optionsJson = json.dumps(self._writeOptions, ensure_ascii=True)
+			cmd.append(quote(f"--json-write-options={optionsJson}"))
+
+		if self._configOptions:
+			for key, value in self._configOptions.items():
+				if value is None:
+					continue
+				option = self.configDefDict.get(key)
+				if option is None:
+					log.error(f"config key {key} was not found")
+				if not option.cmd:
+					log.error(f"config key {key} has no command line flag")
+				flag = option.cmdFlag
+				if not flag:
+					flag = key.replace('_', '-')
+				if option.typ == "bool":
+					if not value:
+						flag = f"no-{flag}"
+					cmd.append(f"--{flag}")
+				else:
+					cmd.append(quote(f"--{flag}={value}"))
+
+		if self._convertOptions:
+			convertOptionsFlags = {
+				"direct": ("indirect", "direct"),
+				"progressbar": ("no-progress-bar", ""),
+				"sort": ("no-sort", "sort"),
+				"sortCacheSize": ("sort-cache-size", ""),
+				"defaultSortKey": None,
+			}
+			for key, value in self._convertOptions.items():
+				if value is None:
+					continue
+				if key not in convertOptionsFlags:
+					log.error(f"unknow key {key} in convertOptions")
+					continue
+				ftup = convertOptionsFlags[key]
+				if ftup is None:
+					continue
+				if isinstance(value, bool):
+					flag = ftup[int(value)]
+					cmd.append(f"--{flag}")
+				else:
+					flag = ftup[0]
+					cmd.append(f"--{flag}={value}")
+
+		print()
+		print(
+			"If you want to repeat this conversion later, "
+			"you can use this command:"
+		)
+		print(" ".join(cmd))
+
 	def run(
 		self,
 		inputFilename: str = "",
@@ -572,6 +811,8 @@ class UI(ui_cmd.UI):
 		del inputFilename, outputFilename, inputFormat, outputFormat
 		del configOptions, readOptions, writeOptions, convertOptions
 
+		self.loadConfig(**self._configOptions)
+
 		if not self._inputFilename:
 			try:
 				self.askInputFile()
@@ -605,6 +846,9 @@ class UI(ui_cmd.UI):
 			except Exception as e:
 				log.exception("")
 			else:
+				self.printNonInteractiveCommand()
 				if succeed:
+					if self._configOptions and confirm("Save Config?"):
+						self.saveConfig()
 					return succeed
 			print("Press Control + C to exit")
