@@ -450,7 +450,7 @@ class InputFormatComboBox(FormatComboBox):
 		return "r"
 
 	def getActiveOptions(self):
-		return Glossary.formatsReadOptions[self.getActive()]
+		return list(Glossary.formatsReadOptions[self.getActive()].keys())
 
 
 class OutputFormatComboBox(FormatComboBox):
@@ -464,7 +464,7 @@ class OutputFormatComboBox(FormatComboBox):
 		return "w"
 
 	def getActiveOptions(self):
-		return Glossary.formatsWriteOptions[self.getActive()]
+		return list(Glossary.formatsWriteOptions[self.getActive()].keys())
 
 
 class GtkTextviewLogHandler(logging.Handler):
@@ -580,17 +580,16 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 		_id = self.statusBar.get_context_id(msg)
 		self.statusBar.push(_id, msg)
 
-	def __init__(self, **options):
+	def __init__(self):
 		gtk.Dialog.__init__(self)
+		UIBase.__init__(self)
 		self.set_title("PyGlossary (Gtk3)")
 		self.resize(800, 800)
 		self.connect("delete-event", self.onDeleteEvent)
-		self.prefPages = []
+		self.pages = []
 		# self.statusNewId = 0
 		# self.statusMsgDict = {}## message -> id
 		#####
-		self.pref = {}
-		self.pref_load(**options)
 		self._convertOptions = {}
 		#####
 		self.assert_quit = False
@@ -602,7 +601,7 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 		vbox = VBox()
 		vbox.label = _("Convert")
 		vbox.icon = ""  # "*.png"
-		self.prefPages.append(vbox)
+		self.pages.append(vbox)
 		######
 		hbox = HBox(spacing=3)
 		hbox.label = gtk.Label(label=_("Input Format")+":")
@@ -697,7 +696,7 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 		vbox = VBox()
 		vbox.label = _("Reverse")
 		vbox.icon = ""  # "*.png"
-		# self.prefPages.append(vbox)
+		# self.pages.append(vbox)
 		######
 		hbox = HBox(spacing=3)
 		hbox.label = gtk.Label(label=_("Input Format")+":")
@@ -793,13 +792,13 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 		)
 		about.label = _("About")
 		about.icon = ""  # "*.png"
-		self.prefPages.append(about)
+		self.pages.append(about)
 		#####
 		# ____________________________________________________________ #
 		notebook = gtk.Notebook()
 		self.notebook = notebook
 		#########
-		for vbox in self.prefPages:
+		for vbox in self.pages:
 			l = gtk.Label(label=vbox.label)
 			l.set_use_underline(True)
 			vb = VBox(spacing=3)
@@ -815,12 +814,12 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 				pass
 		#######################
 		pack(self.vbox, notebook, 1, 1)
-		# for i in ui.prefPagesOrder:
+		# for i in ui.pagesOrder:
 		#	try:
-		#		j = prefPagesOrder[i]
+		#		j = pagesOrder[i]
 		#	except IndexError:
 		#		continue
-		#	notebook.reorder_child(self.prefPages[i], j)
+		#	notebook.reorder_child(self.pages[i], j)
 		# ____________________________________________________________ #
 		handler = GtkSingleTextviewLogHandler(textview)
 		log.addHandler(handler)
@@ -908,6 +907,8 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 		writeOptions: "Optional[Dict]" = None,
 		convertOptions: "Optional[Dict]" = None,
 	):
+		self.loadConfig(**configOptions)
+
 		if inputFilename:
 			self.convertInputEntry.set_text(abspath(inputFilename))
 		if outputFilename:
@@ -921,9 +922,6 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 		if reverse:
 			log.error(f"Gtk interface does not support Reverse feature")
 
-		if configOptions:
-			self.pref.update(configOptions)
-
 		if readOptions:
 			self.convertInputFormatCombo.setOptionsValues(readOptions)
 		if writeOptions:
@@ -1021,9 +1019,10 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 			inPath = urlToPath(inPath)
 			self.convertInputEntry.set_text(inPath)
 
-		if self.pref["ui_autoSetFormat"] and not inFormat:
-			inFormatNew = Glossary.detectInputFormat(inPath, quiet=True)
-			if inFormatNew:
+		if self.config["ui_autoSetFormat"] and not inFormat:
+			inputArgs = Glossary.detectInputFormat(inPath, quiet=True)
+			if inputArgs:
+				inFormatNew = inputArgs[1]
 				self.convertInputFormatCombo.setActive(inFormatNew)
 
 		if not isfile(inPath):
@@ -1040,7 +1039,7 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 			outPath = urlToPath(outPath)
 			self.convertOutputEntry.set_text(outPath)
 
-		if self.pref["ui_autoSetFormat"] and not outFormat:
+		if self.config["ui_autoSetFormat"] and not outFormat:
 			outputArgs = Glossary.detectOutputFormat(
 				filename=outPath,
 				inputFilename=self.convertInputEntry.get_text(),
@@ -1116,9 +1115,11 @@ class UI(gtk.Dialog, MyDialog, UIBase):
 			inPath = urlToPath(inPath)
 			self.reverseInputEntry.set_text(inPath)
 
-		if not inFormat and self.pref["ui_autoSetFormat"]:
-			inFormat = Glossary.detectInputFormat(inPath, quiet=True)
-			self.reverseInputFormatCombo.setActive(inFormat)
+		if not inFormat and self.config["ui_autoSetFormat"]:
+			inputArgs = Glossary.detectInputFormat(inPath, quiet=True)
+			if inputArgs:
+				inFormat = inputArgs[1]
+				self.reverseInputFormatCombo.setActive(inFormat)
 
 	def reverseOutputEntryChanged(self, widget=None):
 		pass
