@@ -306,7 +306,7 @@ class ProgressBar(tix.Frame):
 		self.canvas.update_idletasks()
 
 
-class FormatOptionsButton(ttk.Button):
+class FormatOptionsButton(tk.Button):
 	def __init__(
 		self,
 		kind: "Literal['Read', 'Write']",
@@ -314,13 +314,14 @@ class FormatOptionsButton(ttk.Button):
 		formatVar: tk.StringVar,
 		master=None,
 	):
-		ttk.Button.__init__(
+		tk.Button.__init__(
 			self,
 			master=master,
 			text="Options",
 			command=self.buttonClicked,
 			# bg="#f0f000",
 			# activebackground="#f6f622",
+			borderwidth=3,
 		)
 		self.kind = kind
 		self.kindFormatsOptions = {
@@ -387,7 +388,7 @@ class FormatOptionsButton(ttk.Button):
 
 		button = ttk.Button(
 			frame,
-			text="Ok",
+			text="OK",
 			command=okClicked,
 			# bg="#ff0000",
 			# activebackground="#ff5050",
@@ -402,7 +403,7 @@ class FormatOptionsButton(ttk.Button):
 		if not formatD:
 			return
 		format = pluginByDesc[formatD].name
-		options = self.kindFormatsOptions[self.kind][format]
+		options = list(self.kindFormatsOptions[self.kind][format].keys())
 		optionsProp = Glossary.plugins[format].optionsProp
 
 		dialog = tix.Toplevel()  # bg="#0f0" does not work
@@ -427,7 +428,7 @@ class FormatOptionsButton(ttk.Button):
 			treev.heading(
 				col,
 				text=col,
-				#command=lambda c=col: sortby(treev, c, 0),
+				# command=lambda c=col: sortby(treev, c, 0),
 			)
 			# adjust the column's width to the header string
 			treev.column(
@@ -629,12 +630,7 @@ class FormatOptionsButton(ttk.Button):
 class UI(tix.Frame, UIBase):
 	fcd_dir_save_path = join(confDir, "ui-tk-fcd-dir")
 
-	def __init__(self, path="", **options):
-		self.glos = Glossary(ui=self)
-		self.pref = {}
-		self.pref_load(**options)
-		self._convertOptions = {}
-		#############################################
+	def __init__(self):
 		rootWin = self.rootWin = tix.Tk()
 		# a hack that hides the window until we move it to the center of screen
 		if os.sep == "\\":  # Windows
@@ -642,6 +638,7 @@ class UI(tix.Frame, UIBase):
 		else:  # Linux
 			rootWin.withdraw()
 		tix.Frame.__init__(self, rootWin)
+		UIBase.__init__(self)
 		rootWin.title("PyGlossary (Tkinter)")
 		rootWin.resizable(True, False)
 		########
@@ -650,10 +647,16 @@ class UI(tix.Frame, UIBase):
 		########
 		self.pack(fill="x")
 		# rootWin.bind("<Configure>", self.resized)
+		#######################
+		defaultFont = tkFont.nametofont('TkDefaultFont')
+		if core.sysName in ("linux", "freebsd"):
+			defaultFont.configure(size=int(defaultFont.cget("size") * 1.4))
+		####
+		self.biggerFont = defaultFont.copy()
+		self.biggerFont.configure(size=int(defaultFont.cget("size") * 1.5))
 		######################
 		self.glos = Glossary(ui=self)
-		self.pref = {}
-		self.pref_load()
+		self._convertOptions = {}
 		self.pathI = ""
 		self.pathO = ""
 		fcd_dir = join(homeDir, "Desktop")
@@ -671,21 +674,19 @@ class UI(tix.Frame, UIBase):
 		notebook.add("tabAbout", label="About", underline=0)
 		convertFrame = tix.Frame(notebook.tabConvert)
 		aboutFrame = tix.Frame(notebook.tabAbout)
-		convertVpaned = ttk.PanedWindow(convertFrame, orient=tk.VERTICAL)
 		######################
-		frame = tix.Frame(convertFrame)
-		##
-		label = ttk.Label(frame, text="Read from format")
-		label.pack(side="left")
+		row = 0
+		label = ttk.Label(convertFrame, text="Input Format: ")
+		label.grid(row=row, column=0, sticky=tk.W)
 		##
 		comboVar = tk.StringVar()
 		combo = ttk.OptionMenu(
-			frame,
+			convertFrame,
 			comboVar,
 			None,  # default
 			*readDesc,
 		)
-		combo.pack(side="left")
+		combo.grid(row=row, column=1, sticky=tk.W)
 		comboVar.trace("w", self.inputComboChanged)
 		self.formatVarInputConvert = comboVar
 		##
@@ -696,45 +697,45 @@ class UI(tix.Frame, UIBase):
 			"Read",
 			self.readOptions,
 			self.formatVarInputConvert,
-			master=frame,
+			master=convertFrame,
 		)
-		##
-		frame.pack(fill="x")
+		self.inputFormatRow = row
 		###################
-		frame = tix.Frame(convertFrame)
+		row += 1
+		label = ttk.Label(convertFrame, text="Input File: ")
+		label.grid(row=row, column=0, sticky=tk.W)
 		##
-		label = ttk.Label(frame, text="  Path:")
-		label.pack(side="left")
-		##
-		entry = tix.Entry(frame)
-		entry.pack(side="left", fill="x", expand=True)
+		entry = tix.Entry(convertFrame)
+		entry.grid(row=row, column=1, columnspan=2, sticky=tk.W + tk.E)
 		entry.bind_all("<KeyPress>", self.anyEntryChanged)
 		self.entryInputConvert = entry
 		##
-		button = ttk.Button(
-			frame,
+		button = tk.Button(
+			convertFrame,
 			text="Browse",
 			command=self.browseInputConvert,
 			# bg="#f0f000",
 			# activebackground="#f6f622",
+			borderwidth=3,
 		)
-		button.pack(side="left")
-		##
-		frame.pack(fill="x")
+		button.grid(row=row, column=3, sticky=tk.W + tk.E)
 		######################
-		frame = tix.Frame(convertFrame)
-		##
-		label = ttk.Label(frame, text="Write to format    ")
-		label.pack(side="left")
+		row += 1
+		label = ttk.Label(convertFrame)
+		label.grid(row=row, column=0, sticky=tk.W)
+		######################
+		row += 1
+		label = ttk.Label(convertFrame, text="Output Format: ")
+		label.grid(row=row, column=0, sticky=tk.W)
 		##
 		comboVar = tk.StringVar()
 		combo = ttk.OptionMenu(
-			frame,
+			convertFrame,
 			comboVar,
 			None,  # default
 			*writeDesc,
 		)
-		combo.pack(side="left")
+		combo.grid(row=row, column=1, columnspan=2, sticky=tk.W)
 		comboVar.trace("w", self.outputComboChanged)
 		self.formatVarOutputConvert = comboVar
 		##
@@ -742,157 +743,79 @@ class UI(tix.Frame, UIBase):
 			"Write",
 			self.writeOptions,
 			self.formatVarOutputConvert,
-			master=frame,
+			master=convertFrame,
 		)
-		##
-		frame.pack(fill="x")
+		self.outputFormatRow = row
 		###################
-		frame = tix.Frame(convertFrame)
+		row += 1
+		label = ttk.Label(convertFrame, text="Output File: ")
+		label.grid(row=row, column=0, sticky=tk.W)
 		##
-		label = ttk.Label(frame, text="  Path:")
-		label.pack(side="left")
-		##
-		entry = tix.Entry(frame)
-		entry.pack(side="left", fill="x", expand=True)
+		entry = tix.Entry(convertFrame)
+		entry.grid(row=row, column=1, columnspan=2, sticky=tk.W + tk.E)
 		entry.bind_all("<KeyPress>", self.anyEntryChanged)
 		self.entryOutputConvert = entry
 		##
-		button = ttk.Button(
-			frame,
+		button = tk.Button(
+			convertFrame,
 			text="Browse",
 			command=self.browseOutputConvert,
 			# bg="#f0f000",
 			# activebackground="#f6f622",
+			borderwidth=3,
 		)
-		button.pack(side="left")
-		##
-		frame.pack(fill="x")
-		#######
-		frame = tix.Frame(convertFrame)
-		label = ttk.Label(frame, text=" " * 15)
-		label.pack(
-			side="left",
-			fill="x",
-			expand=True,
-		)
-		button = ttk.Button(
-			frame,
+		button.grid(row=row, column=3, sticky=tk.W + tk.E)
+		###################
+		row += 1
+		label = ttk.Label(convertFrame)
+		label.grid(row=row, column=0, sticky=tk.W)
+		###################
+		row += 1
+		button = tk.Button(
+			convertFrame,
 			text="Convert",
 			command=self.convert,
-			# bg="#00e000",
-			# activebackground="#22f022",
+			background="#00e000",
+			activebackground="#22f022",
+			borderwidth=5,
+			font=self.biggerFont,
+			# pady=10,
 		)
-		button.pack(
-			side="left",
-			fill="x",
-			expand=True,
+		button.grid(
+			row=row,
+			column=2,
+			columnspan=3,
+			sticky=tk.W + tk.E + tk.S,
 		)
-		###
-		frame.pack(fill="x")
-		convertVpaned.add(frame)
+		# print(f"row number for Convert button: {row}")
 		######
 		convertFrame.pack(fill="x")
+		# convertFrame.grid(sticky=tk.W + tk.E + tk.N + tk.S)
 		#################
-		console = tix.Text(convertVpaned, height=15, background="#000000")
+		row += 1
+		console = tix.Text(convertFrame, height=15, background="#000", foreground="#fff")
 		# self.consoleH = 15
 		# sbar = Tix.Scrollbar(
-		#	convertVpaned,
-		#	orien=Tix.VERTICAL,
-		#	command=console.yview
+		# 	convertFrame,
+		# 	orien=Tix.VERTICAL,
+		# 	command=console.yview
 		# )
-		# sbar.grid ( row=0, column=1)
+		# sbar.grid (row=row, column=1)
 		# console["yscrollcommand"] = sbar.set
-		# console.grid()
-		console.pack(fill="both", expand=True)
+		console.grid(
+			row=row,
+			column=0,
+			columnspan=4,
+			sticky=tk.W + tk.E,
+		)
 		log.addHandler(
 			TkTextLogHandler(console),
 		)
 		console.insert("end", "Console:\n")
 		####
-		convertVpaned.add(console)
-		convertVpaned.pack(fill="both", expand=True)
+		console.grid()
 		self.console = console
 		##################
-		# convertVpaned.grid()
-		# bottomFrame.grid()
-		# self.grid()
-		#####################
-		# lbox = Tix.Listbox(convertFrame)
-		# lbox.insert(0, "aaaaaaaa", "bbbbbbbbbbbbbbbbbbbb")
-		# lbox.pack(fill="x")
-		##############
-		# __________________________ Reverse Tab __________________________ #
-		# revFrame = tix.Frame(notebook.tabReverse)
-		# revFrame.pack(fill="x")
-		# ######################
-		# frame = tix.Frame(revFrame)
-		# ##
-		# label = ttk.Label(frame, text="Read from format")
-		# label.pack(side="left")
-		# ##
-		# comboVar = tk.StringVar()
-		# combo = ttk.OptionMenu(
-		# 	frame,
-		# 	comboVar,
-		# 	None, # default
-		# 	*readDesc,
-		# )
-		# combo.pack(side="left")
-		# self.combobox_r_i = comboVar
-		# ##
-		# frame.pack(fill="x")
-		# ###################
-		# frame = tix.Frame(revFrame)
-		# ##
-		# label = ttk.Label(frame, text="  Path:")
-		# label.pack(side="left")
-		# ##
-		# entry = tix.Entry(frame)
-		# entry.pack(side="left", fill="x", expand=True)
-		# # entry.bind_all("<KeyPress>", self.entry_r_i_changed)
-		# self.entry_r_i = entry
-		# ##
-		# button = ttk.Button(
-		# 	frame,
-		# 	text="Browse",
-		# 	command=self.reverseBrowseInput,
-		# 	# bg="#f0f000",
-		# 	# activebackground="#f6f622",
-		# )
-		# button.pack(side="left")
-		# ##
-		# button = ttk.Button(
-		# 	frame,
-		# 	text="Load",
-		# 	command=self.reverseLoad,
-		# 	# bg="#7777ff",
-		# )
-		# button.pack(side="left")
-		# ###
-		# frame.pack(fill="x")
-		# ###################
-		# frame = tix.Frame(revFrame)
-		# ##
-		# label = ttk.Label(frame, text="Output Tabfile")
-		# label.pack(side="left")
-		# ###
-		# entry = tix.Entry(frame)
-		# entry.pack(side="left", fill="x", expand=True)
-		# # entry.bind_all("<KeyPress>", self.entry_r_i_changed)
-		# self.entry_r_o = entry
-		# ##
-		# button = ttk.Button(
-		# 	frame,
-		# 	text="Browse",
-		# 	command=self.reverseBrowseOutput,
-		# 	# bg="#f0f000",
-		# 	# activebackground="#f6f622",
-		# )
-		# button.pack(side="left")
-		# ##
-		# frame.pack(fill="x")
-		# _________________________________________________________________ #
-
 		aboutFrame2 = tix.Frame(aboutFrame)
 		##
 		label = newLabelWithImage(aboutFrame2, file=logo)
@@ -959,14 +882,28 @@ class UI(tix.Frame, UIBase):
 		aboutNotebook.pack(fill="x")
 
 		aboutFrame.pack(fill="x")
+
+		######################
+		tk.Grid.columnconfigure(convertFrame, 0, weight=1)
+		tk.Grid.columnconfigure(convertFrame, 1, weight=30)
+		tk.Grid.columnconfigure(convertFrame, 2, weight=20)
+		tk.Grid.columnconfigure(convertFrame, 3, weight=1)
+		tk.Grid.rowconfigure(convertFrame, 0, weight=50)
+		tk.Grid.rowconfigure(convertFrame, 1, weight=50)
+		tk.Grid.rowconfigure(convertFrame, 2, weight=1)
+		tk.Grid.rowconfigure(convertFrame, 3, weight=50)
+		tk.Grid.rowconfigure(convertFrame, 4, weight=50)
+		tk.Grid.rowconfigure(convertFrame, 5, weight=1)
+		tk.Grid.rowconfigure(convertFrame, 6, weight=50)
+
 		# _________________________________________________________________ #
 
 		notebook.pack(fill="both", expand=True)
 
 		# _________________________________________________________________ #
 
-		statusBarframe = tix.Frame(self)
-		clearB = ttk.Button(
+		statusBarframe = tk.Frame(self, borderwidth=3)
+		clearB = tk.Button(
 			statusBarframe,
 			text="Clear",
 			command=self.console_clear,
@@ -974,6 +911,8 @@ class UI(tix.Frame, UIBase):
 			# fg="#ffff00",
 			# activebackground="#333333",
 			# activeforeground="#ffff00",
+			borderwidth=3,
+			height=2,
 		)
 		clearB.pack(side="left")
 		####
@@ -985,29 +924,18 @@ class UI(tix.Frame, UIBase):
 			statusBarframe,
 			comboVar,
 			log.getVerbosity(),  # default
-			0, 1, 2, 3, 4,
+			0, 1, 2, 3, 4, 5,
 		)
 		comboVar.trace("w", self.verbosityChanged)
 		combo.pack(side="left")
 		self.verbosityCombo = comboVar
 		#####
-		pbar = ProgressBar(statusBarframe, width=400)
+		pbar = ProgressBar(statusBarframe, width=700, height=28)
 		pbar.pack(side="left", fill="x", expand=True)
 		self.pbar = pbar
 		statusBarframe.pack(fill="x")
 		self.progressTitle = ""
 		# _________________________________________________________________ #
-		frame3 = tix.Frame(self)
-		closeB = ttk.Button(
-			frame3,
-			text="Close",
-			command=rootWin.quit,
-			# bg="#ff0000",
-			# activebackground="#ff5050",
-		)
-		closeB.pack(side="right")
-		frame3.pack(fill="x")
-		# _________________________________________________________________ #
 
 		centerWindow(rootWin)
 		# show the window
@@ -1015,11 +943,6 @@ class UI(tix.Frame, UIBase):
 			rootWin.attributes('-alpha', 1.0)
 		else:  # Linux
 			rootWin.deiconify()
-		if path:
-			self.entryInputConvert.insert(0, path)
-			self.inputEntryChanged()
-			self.outputEntryChanged()
-			self.load()
 
 	def verbosityChanged(self, index, value, op):
 		log.setVerbosity(
@@ -1030,13 +953,13 @@ class UI(tix.Frame, UIBase):
 		dh = self.rootWin.winfo_height() - self.winfo_height()
 		# log.debug(dh, self.consoleH)
 		# if dh > 20:
-		#	self.consoleH += 1
-		#	self.console["height"] = self.consoleH
-		#	self.console["width"] = int(self.console["width"]) + 1
-		#	self.console.grid()
+		# 	self.consoleH += 1
+		# 	self.console["height"] = self.consoleH
+		# 	self.console["width"] = int(self.console["width"]) + 1
+		# 	self.console.grid()
 		# for x in dir(self):
-		#	if "info" in x:
-		#		log.debug(x)
+		# 	if "info" in x:
+		# 		log.debug(x)
 
 	def inputComboChanged(self, *args):
 		formatDesc = self.formatVarInputConvert.get()
@@ -1044,11 +967,14 @@ class UI(tix.Frame, UIBase):
 			return
 		self.readOptions.clear()  # reset the options, DO NOT re-assign
 		format = pluginByDesc[formatDesc].name
-		options = Glossary.formatsReadOptions[format]
-		if options:
-			self.readOptionsButton.pack(side="right")
+		if Glossary.formatsReadOptions[format]:
+			self.readOptionsButton.grid(
+				row=self.inputFormatRow,
+				column=3,
+				sticky=tk.W + tk.E,
+			)
 		else:
-			self.readOptionsButton.pack_forget()
+			self.readOptionsButton.grid_forget()
 
 	def outputComboChanged(self, *args):
 		# log.debug(self.formatVarOutputConvert.get())
@@ -1057,11 +983,13 @@ class UI(tix.Frame, UIBase):
 			return
 		self.writeOptions.clear()  # reset the options, DO NOT re-assign
 		format = pluginByDesc[formatDesc].name
-		options = Glossary.formatsWriteOptions[format]
-		if options:
-			self.writeOptionsButton.pack(side="right")
+		if Glossary.formatsWriteOptions[format]:
+			self.writeOptionsButton.grid(
+				row=self.outputFormatRow,
+				column=3, sticky=tk.W + tk.E,
+			)
 		else:
-			self.writeOptionsButton.pack_forget()
+			self.writeOptionsButton.grid_forget()
 
 	def anyEntryChanged(self, event=None):
 		self.inputEntryChanged()
@@ -1075,11 +1003,12 @@ class UI(tix.Frame, UIBase):
 				pathI = urlToPath(pathI)
 				self.entryInputConvert.delete(0, "end")
 				self.entryInputConvert.insert(0, pathI)
-			if self.pref["ui_autoSetFormat"]:
+			if self.config["ui_autoSetFormat"]:
 				formatDesc = self.formatVarInputConvert.get()
 				if not formatDesc:
-					format = Glossary.detectInputFormat(pathI, quiet=True)
-					if format:
+					inputArgs = Glossary.detectInputFormat(pathI, quiet=True)
+					if inputArgs:
+						format = inputArgs[1]
 						plugin = Glossary.plugins.get(format)
 						if plugin:
 							self.formatVarInputConvert.set(plugin.description)
@@ -1092,7 +1021,7 @@ class UI(tix.Frame, UIBase):
 				pathO = urlToPath(pathO)
 				self.entryOutputConvert.delete(0, "end")
 				self.entryOutputConvert.insert(0, pathO)
-			if self.pref["ui_autoSetFormat"]:
+			if self.config["ui_autoSetFormat"]:
 				formatDesc = self.formatVarOutputConvert.get()
 				if not formatDesc:
 					outputArgs = Glossary.detectOutputFormat(
@@ -1184,7 +1113,7 @@ class UI(tix.Frame, UIBase):
 			self.entryInputConvert.insert(0, abspath(inputFilename))
 		if outputFilename:
 			self.entryOutputConvert.insert(0, abspath(outputFilename))
-		
+
 		if inputFormat:
 			self.formatVarInputConvert.set(Glossary.plugins[inputFormat].description)
 		if outputFormat:
@@ -1193,8 +1122,7 @@ class UI(tix.Frame, UIBase):
 		if reverse:
 			log.error(f"Tkinter interface does not support Reverse feature")
 
-		if configOptions:
-			self.pref.update(configOptions)
+		self.loadConfig(**configOptions)
 
 		# must be before setting self.readOptions and self.writeOptions
 		self.anyEntryChanged()
